agentle.mcp.resources
=====================

.. automodule:: agentle.mcp.resources

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   binary_resources
   resource_content
   resource_description
   resource_description_with_template
   text_resources
